<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="报损单单号">
              <j-input placeholder="请输入报损单单号"    v-model="queryParam.orderCode"></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="审核状态">
              <j-dict-select-tag placeholder="请选择审核状态" v-model="queryParam.orderStatus"
                                 dictCode="approval_status"/>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
<!--              <a @click="handleToggleSearch" style="margin-left: 8px">-->
<!--                {{ toggleSearchStatus ? '收起' : '展开' }}-->
<!--                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />-->
<!--              </a>-->
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>

    </div>

    <!-- table区域-begin -->
    <div>


      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        class="j-table-force-nowrap"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
        :customRow="clickThenSelect"
        @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
          <a @click="handleDetail(record)">详情</a>
          <span v-if="record.orderStatus === '1'">
            <a-divider type="vertical" />
            <a-popconfirm title="确定提交吗?" @confirm="() => handleSubmit(record)">
              <a>提交</a>
            </a-popconfirm>
            <a-divider type="vertical" />
            <a-dropdown>
              <a class="ant-dropdown-link">更多<a-icon type="down" /></a>
              <a-menu slot="overlay">
                <a-menu-item>
                  <a @click="handleEdit(record)">编辑</a>
                </a-menu-item>
                <a-menu-item>
                  <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                    <a>删除</a>
                  </a-popconfirm>
                </a-menu-item>
              </a-menu>
            </a-dropdown>
          </span>
        </span>

      </a-table>
    </div>

    <a-tabs defaultActiveKey="1">
      <a-tab-pane tab="报损申请单明细" key="1">
        <LossboundDetailList ref="lossboundDetailList" :mainId="lossboundDetailMainId" />
      </a-tab-pane>
    </a-tabs>

    <lossbound-modal ref="modalForm" @ok="modalFormOk"></lossbound-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LossboundModal from './modules/LossboundModal'
import { deleteAction, getAction } from '@/api/manage'
import LossboundDetailList from './LossboundDetailList.vue'
import '@/assets/less/TableExpand.less'

export default {
  name: 'LooboundList',
  mixins: [JeecgListMixin],
  components: {
    LossboundDetailList,
    LossboundModal
  },
  data() {
    return {
      description: 'tms_outbound_order管理页面',
      // 表头
      columns: [
        {
          title: '报损单单号',
          align: 'center',
          dataIndex: 'orderCode'
        },
        {
          title: '审核状态',
          align: 'center',
          dataIndex: 'orderStatus_dictText'
        },
        {
          title: '经手人',
          align: 'center',
          dataIndex: 'handler_dictText'
        },
        {
          title: '审核人',
          align: 'center',
          dataIndex: 'reviewer_dictText'
        },
        {
          title: '审核时间',
          align: 'center',
          dataIndex: 'auditDate'
        },
        {
          title: '审核意见',
          align: 'center',
          dataIndex: 'approvalOpinion'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/tms/toolsLossBound/list',
        delete: '/tms/toolsLossBound/delete',
        submit: '/tms/toolsLossBound/submit',
        deleteBatch: '/tms/toolsLossBound/deleteBatch',
        exportXlsUrl: '/tms/toolsLossBound/exportXls',
        importExcelUrl: 'tms/toolsLossBound/importExcel'
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      selectedMainId: '',
      superFieldList: [],
      lossboundDetailMainId: ''
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {

    modalFormOk() {
      this.$refs.lossboundDetailList.clearList()
      this.loadData()
    },
    searchReset() {
      this.queryParam = {}
      this.onClearSelected()
      this.$refs.lossboundDetailList.clearList()
      this.loadData(1)
    },
    initDictConfig() {
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.selectedMainId = ''
      this.lossboundDetailMainId = ''
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      this.selectedMainId = selectedRowKeys[0]
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
      this.lossboundDetailMainId = selectionRows[0]['id']
    },
    handleSubmit(record) {
      getAction(this.url.submit, { id: record.id }).then((res) => {
        if (res.success) {
          this.$message.success(res.message)
          this.loadData()
          this.$refs.lossboundDetailList.clearList()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    handleDelete: function(id) {
      if (!this.url.delete) {
        this.$message.error('请设置url.delete属性!')
        return
      }
      var that = this
      deleteAction(that.url.delete, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          // that.$message.success(res.message);
          that.$notification.success({
            message: '消息',
            description: res.message
          })
          that.loadData()
          this.$refs.lossboundDetailList.clearList()
        } else {
          // that.$message.warning(res.message);
          that.$notification.warning({
            message: '消息',
            description: res.message
          })
        }
      })
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'orderCode', text: '出库单编号', dictCode: '' })

      fieldList.push({ type: 'string', value: 'handler', text: '经手人', dictCode: '' })
      fieldList.push({ type: 'sel_user', value: 'reviewer', text: '审核人' })
      fieldList.push({ type: 'string', value: 'orderStatus', text: '审核状态', dictCode: '' })
      fieldList.push({ type: 'date', value: 'auditDate', text: '审核时间' })
      fieldList.push({ type: 'string', value: 'approvalOpinion', text: '审核意见', dictCode: '' })
      fieldList.push({ type: 'string', value: 'subjectMatter', text: '领用事由', dictCode: '' })
      fieldList.push({ type: 'date', value: 'outboundTime', text: '出库时间' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      fieldList.push({ type: 'string', value: 'createBy', text: '操作员', dictCode: '' })
      fieldList.push({ type: 'date', value: 'createTime', text: '创建时间' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>